@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -36,12 +36,54 @@ int GrantleeViewFormatter::pointsToPixel(int pointSize) const
     return (pointSize * mDeviceDpiY + 36) / 72;
 }
 
-void GrantleeViewFormatter::addStandardObject(QVariantHash &grantleeObject)
+void GrantleeViewFormatter::addStandardObject(QVariantHash &grantleeObject) const
 {
     grantleeObject.insert(QStringLiteral("absoluteThemePath"), mGrantleeThemePath);
     grantleeObject.insert(QStringLiteral("applicationDir"), mDirectionString);
     grantleeObject.insert(QStringLiteral("standardFamilyFont"), Settings::standardFont());
     grantleeObject.insert(QStringLiteral("mediumFontSize"), Settings::mediumFontSize());
+    grantleeObject.insert(QStringLiteral("sidebarCss"), sidebarCss());
+}
+
+QString GrantleeViewFormatter::sidebarCss() const
+{
+    return QStringLiteral(
+        "html::-webkit-scrollbar {\n"
+        "  /* we'll add padding as \"border\" in the thumb*/\n"
+        "    height: 20px;\n"
+        "    width: 20px;\n"
+        "    background: white;\n"
+        "    border-left: 1px solid #e5e5e5;\n"
+        "    padding-left: 1px;\n"
+        "}\n\n"
+
+        "html::-webkit-scrollbar-track {\n"
+        "    border-radius: 20px;\n"
+        "    width: 6px !important;\n"
+        "    box-sizing: content-box;\n"
+        "}\n\n"
+
+        "html::-webkit-scrollbar-thumb {\n"
+        "    background-color: #CBCDCD;\n"
+        "    border: 6px solid transparent;\n"
+        "    border-radius: 20px;\n"
+        "    background-clip: content-box;\n"
+        "    width: 8px !important; /* 20px scrollbar - 2 * 6px border */\n"
+        "    box-sizing: content-box;\n"
+        "    min-height: 30px;\n"
+        "}\n\n"
+
+        "html::-webkit-scrollbar-thumb:window-inactive {\n"
+        "   background-color: #949699; /* when window is inactive it's gray */\n"
+        "}\n\n"
+
+        "html::-webkit-scrollbar-thumb:hover {\n"
+        "    background-color: #93CEE9; /* hovered is a lighter blue */\n"
+        "}\n\n"
+
+        "html::-webkit-scrollbar-corner {\n"
+        "    background-color: white;\n"
+        "}\n\n");
 }
 
 QString GrantleeViewFormatter::formatFeed(Akregator::Feed *feed)
